===============
django-disguise
===============

.. image:: https://badge.fury.io/py/django-disguise.png
    :target: http://badge.fury.io/py/django-disguise

.. image:: https://travis-ci.org/marazmiki/django-disguise.png?branch=master
    :target: https://travis-ci.org/marazmiki/django-disguise

.. image:: https://coveralls.io/repos/marazmiki/django-disguise/badge.png?branch=master
    :target: https://coveralls.io/r/marazmiki/django-disguise?branch=master

.. image:: https://pypip.in/d/django-disguise/badge.png
    :target: https://pypi.python.org/pypi/django-disguise

.. image:: https://pypip.in/d/django-disguise/badge.png
    :target: https://pypi.python.org/pypi/django-disguise
    :alt: Latest version on PyPI


.. image:: https://pypip.in/wheel/django-disguise/badge.svg
    :target: https://pypi.python.org/pypi/django-disguise/
    :alt: Wheel Status



